<?php
/**
 * Class Suprimentos\Repositories
 *
 * @category Php
 * @package  Suprimentos\Repositories
 * @author   matthaeuscarvalho <matthaeus.carvalho@teknisa.com>
 * @license  www.teknisa.com Teknisa
 * @link     http://localhost:9090/tecfood
 */
namespace Suprimentos\Repositories;

use Geral\Util\TratamentoDeMensagens;

/**
 * Class Prodforncomp
 *
 * @category Php
 * @package  Suprimentos\Repositories
 * @author   matthaeuscarvalho <matthaeus.carvalho@teknisa.com>
 * @license  www.teknisa.com Teknisa
 * @link     http://localhost:9090/tecfood
 */
class Prodforncomp extends \Doctrine\ORM\EntityRepository
{
    /**
     * Verifica Qualificacao Produto Fornecedor
     *
     * @param String $nrorg      Organização
     * @param String $cdforneced Fornecedor
     * @param String $tforn      Todos Fornecedores
     * @param String $cdprodini  Produto Inicial
     * @param String $cdprodfin  Produto Final
     * @param String $tproduto   Todos Produtos
     * @param String $cdfilial   Filial
     *
     * @throws \Exception
     * @return       array
     */
    public function verificaQualificacaoProdutoFornecedor(
        $nrorg, $cdforneced, $tforn, $cdprodini, $cdprodfin, $tproduto, $cdfilial
    ) {
        $sql = <<<SQL
                SELECT PRODFORNCOMP.CDPRODUTO,
                  PF.NMPRODUTO
                FROM PRODFORNCOMP,
                  PARASUPRI,
                  PRODUTO PF
                WHERE
                    (:P_CDFORNECED LIKE '%' || PRODFORNCOMP.CDFORNECED || '%' OR :P_TFORN = 'T')
                    AND (PF.CDARVPROD BETWEEN :P_CDPRODINI AND :P_CDPRODFIN OR :P_TPRODUTO = 'T')
                    AND (PRODFORNCOMP.CDPRODCOMPL = PF.CDPRODUTO)
                    AND (PARASUPRI.NRORG          = :P_NRORG)
                    AND (PARASUPRI.CDFILIAL       = :P_CDFILIAL)
                    AND ((PARASUPRI.IDUTLPROCMP   = 'N') OR (PARASUPRI.IDUTLPROCMP = 'S'
                          AND PF.CDPRODUTO <> PF.CDPRODESTO))
SQL;

        $cdforneced = $cdforneced["cdforneced"];

        $params = array(
            'P_CDFORNECED' => $cdforneced,
            'P_TFORN' => $tforn,
            'P_CDPRODINI' => $cdprodini,
            'P_CDPRODFIN' => $cdprodfin,
            'P_TPRODUTO' => $tproduto,
            'P_CDFILIAL' => $cdfilial,
            'P_NRORG' => $nrorg
        );

        try {
            return self::getEntityManager()->getConnection()->fetchArray($sql, $params);
        } catch (\Exception $e) {
            throw $e;
        }
    }
}